import uuid

import click
from click_didyoumean import DYMGroup
import click_log
import logging

from terminaltables import SingleTable

from carom.table import cleanup

logger = logging.getLogger('carom.cli')  # hard coded module name to support directly called module
root_logger = logging.getLogger('')
click_log.basic_config(root_logger)


@click.group(cls=DYMGroup)
@click_log.simple_verbosity_option(root_logger)
def cli():
    pass


@cli.command()
def get_gpio():
    """
    Get the current status of all Tables.
    """
    from carom.table import tables
    table_data = [("Table #", "Port", "in use")]
    for table in tables:
        table_data.append((table.num, table.port, table.in_use))
    st = SingleTable(table_data)
    st.title = "Tables"
    print(st.table)



@cli.command()
def get_uuid():
    """
    Get the UUID of the Client. This is need to add a new client to the carom server installation.
    """
    click.echo(uuid.uuid5(uuid.NAMESPACE_DNS, str(uuid.getnode())))


@cli.command()
def run():
    """
    This command runs the carom-client daemon process.
    """
    pass


@cli.command()
def check_config():
    """
    This command checks the config for carom client.
    """
    from carom.config import config, log_config
    if config:
        logger.info("Configuration OK")
    else:
        logger.warning("Compiled configuration:")
        log_config()
        exit(1)


if __name__ == "__main__":
    try:
        cli()
    finally:
        cleanup()
